summaryrefslogtreecommitdiffstats
path: root/kdat/ktreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/ktreeview.h')
-rw-r--r--kdat/ktreeview.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/kdat/ktreeview.h b/kdat/ktreeview.h
index bd20d7c..d0af2d5 100644
--- a/kdat/ktreeview.h
+++ b/kdat/ktreeview.h
@@ -61,7 +61,7 @@ public:
/**
* Appends a new (direct) child item at the end. It does not update
* administrative data in newChild except for its tqparent (which is this
* item) and owner.
*/
void appendChild(KTreeViewItem* newChild);
@@ -100,7 +100,7 @@ public:
KTreeViewItem* getChild() const;
/**
* Returns a pointer to the tqparent of this item, or 0 if none.
*/
KTreeViewItem* getParent() const;
@@ -128,7 +128,7 @@ public:
bool hasChild() const;
/**
* Indicates whether this item has a tqparent.
*/
bool hasParent() const;
@@ -142,7 +142,7 @@ public:
* Inserts the a new (direct) child in this item before the child at
* the specified index (first child is index 0). If there is no child
* at the specified index, the item is appended. It does not update
* administrative data in newChild except for its tqparent (which is this
* item) and owner.
*/
void insertChild(int index, KTreeViewItem* newChild);
@@ -224,7 +224,7 @@ protected:
virtual int height(const TQFontMetrics& fm) const;
/**
* Paints the item: pixmap, text, expand button, tqparent branches
*/
virtual void paint(TQPainter* p, int indent,
const TQColorGroup& cg, bool highlighted) const;
@@ -286,7 +286,7 @@ protected:
bool doText;
mutable TQRect expandButton; /* is set in paint() */
KTreeViewItem* child;
- KTreeViewItem* tqparent;
+ KTreeViewItem* parent;
KTreeViewItem* sibling;
TQPixmap pixmap;
TQString text;
@@ -331,7 +331,7 @@ typedef bool (*KForEvery)
by the programmer.
* The list items can be returned by index or logical path and the tree
- navigated by tqparent, child or sibling references contained in them. Also,
+ navigated by parent, child or sibling references contained in them. Also,
item information such as text, pixmap, branch level can be obtained.
* Items can be inserted, changed and removed either by index in the visible
@@ -407,7 +407,7 @@ public:
* current item to -1, and sets default values for scroll bars (both
* auto).
*/
- KTreeView(TQWidget* tqparent = 0, const char* name = 0, WFlags f = 0);
+ KTreeView(TQWidget* parent = 0, const char* name = 0, WFlags f = 0);
/*
* Desctructor. Deletes all items from the topmost level that have been
@@ -425,7 +425,7 @@ public:
int index);
/**
* Same as above except that the tqparent item is specified by a path.
*/
void appendChildItem(const TQString & theText, const TQPixmap& thePixmap,
const KPath& thePath);
@@ -438,7 +438,7 @@ public:
void appendChildItem(KTreeViewItem* newItem, int index);
/**
* Same as above except that the tqparent item is specified by a path.
*/
void appendChildItem(KTreeViewItem* newItem, const KPath& thePath);
@@ -515,7 +515,7 @@ public:
void expandItem(int index);
/**
- Returns the depth to which all tqparent items are automatically
+ Returns the depth to which all parent items are automatically
expanded.
*/
int expandLevel() const;
@@ -622,7 +622,7 @@ public:
/**
* Outdents the item at the given row one level so that it becomes a
* sibling of its tqparent.
*/
void join(int index);
@@ -870,7 +870,7 @@ public:
protected:
virtual void updateCellWidth();
virtual void updateVisibleItems();
- void updateVisibleItemRec(KTreeViewItem* tqparent, int& count, int& width);
+ void updateVisibleItemRec(KTreeViewItem* parent, int& count, int& width);
KTreeViewItem* treeRoot;
bool clearing;
@@ -61,7 +61,7 @@ public:
/**
* Appends a new (direct) child item at the end. It does not update
- * administrative data in newChild except for its tqparent (which is this
+ * administrative data in newChild except for its parent (which is this
* item) and owner.
*/
@@ -100,7 +100,7 @@ public:
KTreeViewItem* getChild() const;
/**
- * Returns a pointer to the tqparent of this item, or 0 if none.
+ * Returns a pointer to the parent of this item, or 0 if none.
*/
KTreeViewItem* getParent() const;
@@ -128,7 +128,7 @@ public:
bool hasChild() const;
/**
- * Indicates whether this item has a tqparent.
+ * Indicates whether this item has a parent.
*/
bool hasParent() const;
@@ -142,7 +142,7 @@ public:
* the specified index (first child is index 0). If there is no child
* at the specified index, the item is appended. It does not update
- * administrative data in newChild except for its tqparent (which is this
+ * administrative data in newChild except for its parent (which is this
* item) and owner.
*/
@@ -224,7 +224,7 @@ protected:
virtual int height(const TQFontMetrics& fm) const;
/**
- * Paints the item: pixmap, text, expand button, tqparent branches
+ * Paints the item: pixmap, text, expand button, parent branches
*/
virtual void paint(TQPainter* p, int indent,
@@ -425,7 +425,7 @@ public:
int index);
/**
- * Same as above except that the tqparent item is specified by a path.
+ * Same as above except that the parent item is specified by a path.
*/
void appendChildItem(const TQString & theText, const TQPixmap& thePixmap,
@@ -438,7 +438,7 @@ public:
void appendChildItem(KTreeViewItem* newItem, int index);
/**
- * Same as above except that the tqparent item is specified by a path.
+ * Same as above except that the parent item is specified by a path.
*/
void appendChildItem(KTreeViewItem* newItem, const KPath& thePath);
@@ -622,7 +622,7 @@ public:
/**
* Outdents the item at the given row one level so that it becomes a
- * sibling of its tqparent.
+ * sibling of its parent.
*/
void join(int index);